@@ -2,14 +2,25 @@
 """Configure Minetest server."""
 
 import pathlib
+import shutil
 
 import augeas
 
 from plinth import action_utils
 from plinth.actions import privileged
 
-CONFIG_FILE = '/etc/minetest/minetest.conf'
-AUG_PATH = '/files' + CONFIG_FILE + '/.anon'
+old_config_file = pathlib.Path('/etc/minetest/minetest.conf')
+config_file = pathlib.Path('/etc/luanti/default.conf')
+AUG_PATH = '/files' + str(config_file) + '/.anon'
+
+
+@privileged
+def setup() -> None:
+    """Migrate old configuration file."""
+    if old_config_file.exists():
+        old_config_file.rename(config_file)
+        action_utils.service_daemon_reload()
+        action_utils.service_try_restart('luanti-server')
 
 
 @privileged
@@ -17,7 +28,7 @@ def configure(max_players: int | None = None, enable_pvp: bool | None = None,
               creative_mode: bool | None = None,
               enable_damage: bool | None = None):
     """Update configuration file and restart daemon if necessary."""
-    pathlib.Path(CONFIG_FILE).parent.mkdir(exist_ok=True)
+    config_file.parent.mkdir(exist_ok=True)
     aug = load_augeas()
     if max_players is not None:
         aug.set(AUG_PATH + '/max_users', str(max_players))
@@ -32,7 +43,7 @@ def configure(max_players: int | None = None, enable_pvp: bool | None = None,
         aug.set(AUG_PATH + '/enable_damage', str(enable_damage).lower())
 
     aug.save()
-    action_utils.service_try_restart('minetest-server')
+    action_utils.service_try_restart('luanti-server')
 
 
 def load_augeas():
@@ -40,6 +51,15 @@ def load_augeas():
     aug = augeas.Augeas(flags=augeas.Augeas.NO_LOAD +
                         augeas.Augeas.NO_MODL_AUTOLOAD)
     aug.set('/augeas/load/Php/lens', 'Php.lns')
-    aug.set('/augeas/load/Php/incl[last() + 1]', CONFIG_FILE)
+    aug.set('/augeas/load/Php/incl[last() + 1]', str(config_file))
     aug.load()
     return aug
+
+
+@privileged
+def uninstall() -> None:
+    """Remove the data directory that luanti-server package fails to remove.
+
+    See: https://bugs.debian.org/1122677
+    """
+    shutil.rmtree('/var/lib/private/luanti/default/')
