@@ -1,7 +1,5 @@
 # SPDX-License-Identifier: AGPL-3.0-or-later
-"""
-URLs for the upgrades module
-"""
+"""URLs for the upgrades module."""
 
 from django.urls import re_path
 
@@ -16,6 +14,9 @@ urlpatterns = [
             views.BackportsFirstbootView.as_view(),
             name='backports-firstboot'),
     re_path(r'^sys/upgrades/upgrade/$', views.upgrade, name='upgrade'),
-    re_path(r'^sys/upgrades/test-dist-upgrade/$', views.test_dist_upgrade,
-            name='test-dist-upgrade'),
+    re_path(r'^sys/upgrades/dist-upgrade/$', views.DistUpgradeView.as_view(),
+            name='dist-upgrade'),
+    re_path(r'^sys/upgrades/dist-upgrade/confirm/$',
+            views.DistUpgradeConfirmView.as_view(),
+            name='dist-upgrade-confirm'),
 ]
